@@ -17,37 +17,37 @@
 
 #include "scrobbleconfigdlg.h"
 #include "scrobbler.h"
+#include "juk_debug.h"
 
-#include <KDebug>
 #include <KLineEdit>
-#include <KPushButton>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KWallet>
 
+#include <QPushButton>
 #include <QLayout>
 #include <QLabel>
 #include <QFormLayout>
 
-
-
-ScrobbleConfigDlg::ScrobbleConfigDlg(QWidget* parent, Qt::WindowFlags f)
-    : KDialog(parent, f)
-    , m_wallet(0)
+ScrobbleConfigDlg::ScrobbleConfigDlg(QWidget* parent)
+  : QDialog(parent)
+  , m_wallet(Scrobbler::openKWallet())
 {
     setWindowTitle(i18n("Configure scrobbling..."));
-    
-    setButtons(Apply | Cancel);
-    
+
     m_passwordEdit = new KLineEdit(this);
     m_passwordEdit->setPasswordMode(true);
     m_usernameEdit = new KLineEdit(this);
-    m_testButton = new KPushButton(i18n("Test login..."), this);
+    m_testButton = new QPushButton(i18n("Test login..."), this);
     m_testFeedbackLabel = new QLabel("");
-    
+
+    auto vboxLayout = new QVBoxLayout(this);
+
     QWidget *mainWidget = new QWidget();
-    QFormLayout *layout = new QFormLayout();
-    mainWidget->setLayout(layout);
-    QLabel *infoLabel = new QLabel(i18n("Please enter your <a href=\"http://last.fm/\">last.fm</a> login credentials:"));
+    QFormLayout *layout = new QFormLayout(mainWidget);
+    QLabel *infoLabel = new QLabel(i18n("Please enter your <a href=\"https://last.fm/\">last.fm</a> login credentials:"));
     infoLabel->setOpenExternalLinks(true);
     infoLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     layout->addRow(infoLabel);
@@ -55,19 +55,23 @@ ScrobbleConfigDlg::ScrobbleConfigDlg(QWidget* parent, Qt::WindowFlags f)
     layout->addRow(new QLabel(i18n("Password:")), m_passwordEdit);
     layout->addRow(m_testButton);
     layout->addRow(m_testFeedbackLabel);
-    
+
+    auto dlgButtonBox = new QDialogButtonBox(QDialogButtonBox::Save | QDialogButtonBox::Cancel);
+    vboxLayout->addWidget(mainWidget);
+    vboxLayout->addStretch();
+    vboxLayout->addWidget(dlgButtonBox);
+
     connect(m_passwordEdit, SIGNAL(textEdited(QString)), this, SLOT(valuesChanged()));
     connect(m_usernameEdit, SIGNAL(textEdited(QString)), this, SLOT(valuesChanged()));
     connect(m_testButton, SIGNAL(clicked(bool)), this, SLOT(testLogin()));
-    connect(this, SIGNAL(applyClicked()), this, SLOT(save()));
-    
-    setMainWidget(mainWidget);
+
+    connect(dlgButtonBox, &QDialogButtonBox::accepted, this, &ScrobbleConfigDlg::save);
+    connect(dlgButtonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+
+    m_saveButton = dlgButtonBox->button(QDialogButtonBox::Save);
 
     // Loading credentials using either KWallet or KConfigGroup.
-    m_wallet = Scrobbler::openKWallet();
-
     if (m_wallet) {
-
         QMap<QString, QString> scrobblingCredentials;
         m_wallet->readMap("Scrobbling", scrobblingCredentials);
 
@@ -75,37 +79,27 @@ ScrobbleConfigDlg::ScrobbleConfigDlg(QWidget* parent, Qt::WindowFlags f)
             m_usernameEdit->setText(scrobblingCredentials.value("Username"));
             m_passwordEdit->setText(scrobblingCredentials.value("Password"));
         }
-
     } else {
-
         // Warning message, KWallet is safer than KConfig.
         KMessageBox::information(this, i18n("KWallet is unavailable, your Last.fm credentials will be stored without encryption."), i18n("KWallet is unavailable"));
 
-        KConfigGroup config(KGlobal::config(), "Scrobbling");
+        KConfigGroup config(KSharedConfig::openConfig(), "Scrobbling");
         m_usernameEdit->setText(config.readEntry("Username", ""));
         m_passwordEdit->setText(config.readEntry("Password", ""));
     }
 
     if (m_passwordEdit->text().isEmpty() || m_usernameEdit->text().isEmpty()) {
-        button(Apply)->setEnabled(false);
+        m_saveButton->setEnabled(false);
         m_testButton->setEnabled(false);
     }
 }
 
-ScrobbleConfigDlg::~ScrobbleConfigDlg()
-{
-    delete m_wallet;
-}
-
 void ScrobbleConfigDlg::valuesChanged()
 {
-    if (m_usernameEdit->text().isEmpty() || m_passwordEdit->text().isEmpty())
-        m_testButton->setEnabled(false);
-
-    else
-        m_testButton->setEnabled(true);
-
-    button(Apply)->setEnabled(false);
+    m_testButton->setEnabled(
+            !m_usernameEdit->text().isEmpty() &&
+            !m_passwordEdit->text().isEmpty());
+    m_saveButton->setEnabled(false);
 }
 
 void ScrobbleConfigDlg::save()
@@ -120,12 +114,12 @@ void ScrobbleConfigDlg::save()
 
         if (!m_wallet->writeMap("Scrobbling", scrobblingCredentials)) {
 
-            kError() << "Couldn't save Last.fm credentials using KWallet.";
+            qCCritical(JUK_LOG) << "Couldn't save Last.fm credentials using KWallet.";
         }
 
     } else {
 
-        KConfigGroup config(KGlobal::config(), "Scrobbling");
+        KConfigGroup config(KSharedConfig::openConfig(), "Scrobbling");
         config.writeEntry("Username", m_usernameEdit->text());
         config.writeEntry("Password", m_passwordEdit->text());
     }
@@ -146,7 +140,7 @@ void ScrobbleConfigDlg::invalidLogin()
     m_testFeedbackLabel->setText(i18n("Login invalid."));
     setEnabled(true);
     sender()->deleteLater();
-    button(Apply)->setEnabled(false);
+    m_saveButton->setEnabled(false);
 }
 
 void ScrobbleConfigDlg::validLogin()
@@ -154,5 +148,5 @@ void ScrobbleConfigDlg::validLogin()
     m_testFeedbackLabel->setText(i18n("Login valid."));
     setEnabled(true);
     sender()->deleteLater();
-    button(Apply)->setEnabled(true);
+    m_saveButton->setEnabled(true);
 }
